@@ -6,7 +6,7 @@
 # - call 'Convertgmodels1.sh' to convert special characters
 #
 # Author:   Georg Fleischmann
-# modified: 2005-08-31
+# modified: 2005-11-06
 #
 
 CENON=`echo $0 | sed -e 's|Nib2gmodel.sh||'`
@@ -60,7 +60,7 @@ do
     done
 
     # ProjectSettingsPanel
-    for nib in ProjectSettingsPanel PSInfo
+    for nib in ProjectSettingsPanel PSInfo PSSettings
     do
         echo ProjectSettingsPanel.subproj/$lng.lproj/$nib.nib
         nib2gmodel ProjectSettingsPanel.subproj/$lng.lproj/$nib.nib ProjectSettingsPanel.subproj/$lng.lproj/$nib.gmodel
